HasOne class Associations

Defines a one-to-one association where the foreign key exists on the target model.

Constructors

HasOne(Type model, {String? foreignKey, String? as, String? sourceKey})
const

Properties

as String?
final
foreignKey String?
final
hashCode int
The hash code for this object.
no setterinherited
model Type
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceKey String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited