ModelNameOption class
An object with two attributes, singular and plural, which are used when this model is associated to others.
Constructors
- ModelNameOption({required String singular, required String plural})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, String> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited