Transaction class Querying

Represents a transaction.

Transactions can be managed (using Sequelize.transaction with a callback) or unmanaged (manual commit/rollback).

Constructors

Transaction(String transactionId, BridgeClient _bridge)

Properties

hashCode int
The hash code for this object.
no setterinherited
isFinished bool
Whether the transaction has been committed or rolled back.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transactionId String
The unique ID of the transaction in the bridge.
final

Methods

commit() Future<void>
Commit the transaction.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rollback() Future<void>
Rollback the transaction.
scope<T>(Future<T> fn()) Future<T>
Runs fn within a Zone where this transaction is automatically inherited by Sequelize operations.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

current Transaction?
Get the current transaction in the active Zone, if any.
no setter