Query class
Constructors
-
Query({QueryOperator? where, List<
IncludeBuilder> ? include, dynamic order, dynamic group, int? limit, int? offset, QueryAttributes? attributes, bool? paranoid}) - Query.fromCallbacks({Function? where, Function? include, dynamic columns, dynamic includeHelper, dynamic order, dynamic group, int? limit, int? offset, QueryAttributes? attributes, bool? paranoid})
-
Create a Query from callbacks
This is used internally by findAll/findOne to resolve callbacks
factory
Properties
- attributes → QueryAttributes?
-
final
- group → dynamic
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
include
→ List<
IncludeBuilder> ? -
final
- limit → int?
-
final
- offset → int?
-
final
- order → dynamic
-
final
- paranoid → bool?
-
If false, includes soft-deleted records (for paranoid tables)
@default true (excludes soft-deleted records)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- where → QueryOperator?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert query to JSON format
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited